<?php
class Rethink_Customizer {
    public static function Rethink_Register($wp_customize) {
        self::Rethink_Sections($wp_customize);
        self::Rethink_Controls($wp_customize);
    }
    public static function Rethink_Sections($wp_customize) {
        /**
         * General Section
         */
        $wp_customize->add_section('general_setting_section', array(
            'title' => __('General Settings', 'rethink'),
            'description' => __('Allows you to Contact Info, Menu Text etc settings for Rethink Theme.', 'rethink'), //Descriptive tooltip
            'panel' => '',
            'priority' => '10',
            'capability' => 'edit_theme_options'
            )
        );
        /**
         * Social Icon Section
         */
        $wp_customize->add_section('social_icon', array(
            'title' => __('Social Icon Setting', 'rethink'),
            'description' => __('Allows you to setup Social Icon Section for Rethink Theme.', 'rethink'),
            'panel' => '',
            'priority' => '12',
            'capability' => 'edit_theme_options'
                )
        );
         $wp_customize->remove_section("colors");
    }
    public static function Rethink_Section_Content() {
        $section_content = array(
            'general_setting_section' => array(
                'rethink_logo',
                'rethink_favicon'
            ),         
             'social_icon' => array(
                'rethink_facebook',
                 'rethink_twitter',
                 'rethink_yahoo'
            )
        );
        return $section_content;
    }
    public static function Rethink_Settings() {
        $rethink_settings = array( 
            'rethink_logo' => array(
                'id' => 'rethink_options[rethink_logo]',
                'label' => __('Custom Logo', 'rethink'),
                'description' => __('Upload a logo for your Website. The recommended size for the logo is 221px width x 84px height.', 'rethink'),
                'type' => 'option',
                'setting_type' => 'image',
                'default' => get_template_directory_uri() . '/images/logo.png'
            ),
            'rethink_favicon' => array(
                'id' => 'rethink_options[rethink_favicon]',
                'label' => __('Custom Favicon', 'rethink'),
                'description' => __('Here you can upload a Favicon for your Website. Specified size is 16px x 16px.', 'rethink'),
                'type' => 'option',
                'setting_type' => 'image',
                'default' => ''
            ),
            'rethink_facebook' => array(
                'id' => 'rethink_options[rethink_facebook]',
                'label' => __('Facebook URL', 'rethink'),
                'description' => __('Enter your Facebook URL if you have one', 'rethink'),
                'type' => 'option',
                'setting_type' => 'link',
                'default' => ''
            ),
            'rethink_twitter' => array(
                'id' => 'rethink_options[rethink_twitter]',
                'label' => __('Twitter URL', 'rethink'),
                'description' => __('Enter your Twitter URL if you have one', 'rethink'),
                'type' => 'option',
                'setting_type' => 'link',
                'default' => ''
            ),
            'rethink_yahoo' => array(
                'id' => 'rethink_options[rethink_yahoo]',
                'label' => __('RSS URL', 'rethink'),
                'description' => __('Enter your RSS Feed URL if you have one', 'rethink'),
                'type' => 'option',
                'setting_type' => 'link',
                'default' => ''
            ),
         );
        return $rethink_settings;
    }
    public static function Rethink_Controls($wp_customize) {
        $sections = self::Rethink_Section_Content();
        $settings = self::Rethink_Settings();
        foreach ($sections as $section_id => $section_content) {
            foreach ($section_content as $section_content_id) {
                switch ($settings[$section_content_id]['setting_type']) {
                    case 'image':
                        self::add_setting($wp_customize, $settings[$section_content_id]['id'], $settings[$section_content_id]['default'], $settings[$section_content_id]['type'], 'rethink_sanitize_url');
                        $wp_customize->add_control(new WP_Customize_Image_Control(
                                $wp_customize, $settings[$section_content_id]['id'], array(
                            'label' => $settings[$section_content_id]['label'],
                            'description' => $settings[$section_content_id]['description'],
                            'section' => $section_id,
                            'settings' => $settings[$section_content_id]['id']
                                )
                        ));
                        break;
                    case 'text':
                        self::add_setting($wp_customize, $settings[$section_content_id]['id'], $settings[$section_content_id]['default'], $settings[$section_content_id]['type'], 'rethink_sanitize_text');
                        $wp_customize->add_control(new WP_Customize_Control(
                                $wp_customize, $settings[$section_content_id]['id'], array(
                            'label' => $settings[$section_content_id]['label'],
                            'description' => $settings[$section_content_id]['description'],
                            'section' => $section_id,
                            'settings' => $settings[$section_content_id]['id'],
                            'type' => 'text'
                                )
                        ));
                        break;
                    case 'textarea':
                        self::add_setting($wp_customize, $settings[$section_content_id]['id'], $settings[$section_content_id]['default'], $settings[$section_content_id]['type'], 'rethink_sanitize_textarea');
                        $wp_customize->add_control(new WP_Customize_Control(
                                $wp_customize, $settings[$section_content_id]['id'], array(
                            'label' => $settings[$section_content_id]['label'],
                            'description' => $settings[$section_content_id]['description'],
                            'section' => $section_id,
                            'settings' => $settings[$section_content_id]['id'],
                            'type' => 'textarea'
                                )
                        ));
                        break;
                    case 'link':
                        self::add_setting($wp_customize, $settings[$section_content_id]['id'], $settings[$section_content_id]['default'], $settings[$section_content_id]['type'], 'rethink_sanitize_url');

                        $wp_customize->add_control(new WP_Customize_Control(
                                $wp_customize, $settings[$section_content_id]['id'], array(
                            'label' => $settings[$section_content_id]['label'],
                            'description' => $settings[$section_content_id]['description'],
                            'section' => $section_id,
                            'settings' => $settings[$section_content_id]['id'],
                            'type' => 'text'
                                )
                        ));
                        break;
                    default:
                        break;
                }
            }
        }
    }
  public static function add_setting($wp_customize, $setting_id, $default, $type, $sanitize_callback) {
        $wp_customize->add_setting($setting_id, array(
            'default' => $default,
            'capability' => 'edit_theme_options',
            'sanitize_callback' => array('Rethink_Customizer', $sanitize_callback),
            'type' => $type
                )
        );
    }
    /**
     * adds sanitization callback funtion : textarea
     * @package Rethink
     */
    public static function rethink_sanitize_textarea($value) {
        $value = esc_html($value);
        return $value;
    }
    /**
     * adds sanitization callback funtion : url
     * @package Rethink
     */
    public static function rethink_sanitize_url($value) {
        $value = esc_url($value);
        return $value;
    }
    /**
     * adds sanitization callback funtion : text
     * @package Rethink
     */
    public static function rethink_sanitize_text($value) {
        $value = sanitize_text_field($value);
        return $value;
    }
    /**
     * adds sanitization callback funtion : email
     * @package Rethink
     */
    public static function rethink_sanitize_email($value) {
        $value = sanitize_email($value);
        return $value;
    }
    /**
     * adds sanitization callback funtion : number
     * @package Rethink
     */
    public static function rethink_sanitize_number($value) {
        $value = preg_replace("/[^0-9+ ]/", "", $value);
        return $value;
    }
}
// Setup the Theme Customizer settings and controls...
add_action('customize_register', array('Rethink_Customizer', 'Rethink_Register'));
function inkthemes_registers() {
          wp_register_script( 'inkthemes_jquery_ui', '//code.jquery.com/ui/1.11.0/jquery-ui.js', array("jquery"), true  );
	wp_register_script( 'inkthemes_customizer_script', get_template_directory_uri() . '/js/inkthemes_customizer.js', array("jquery","inkthemes_jquery_ui"), true  );
	wp_enqueue_script( 'inkthemes_customizer_script' );
	wp_localize_script( 'inkthemes_customizer_script', 'ink_advert', array(
            'pro' => __('View PRO version','rethink'),
            'url' => esc_url('http://www.inkthemes.com/wp-themes/rethink-product-review-wordpress-theme/')
            )
            );
}
add_action( 'customize_controls_enqueue_scripts', 'inkthemes_registers' );